#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <algorithm>
#include <cassert>

using namespace std;
using vi = vector<int>;

ostream& operator<<(ostream& os, const vi& v) {
    if (v.empty()) return os << "{}";
    os << "{" << v[0];
    for (int i = 1; i < v.size(); ++i) {
        cout << ", " << v[i];
    }
    return os << "}";
}

constexpr int MAX_EMPLOYEES = 32;
constexpr int MAX_DAYS = 11;
int num_employees, num_days;
int orders[MAX_DAYS];
int ans = 0;

vector<vi> follow;
// state: partition, current split, day, idx
set<pair<vi, vi>> seen[MAX_DAYS][MAX_EMPLOYEES][MAX_EMPLOYEES / 2 + 1];

void fast_insert(vi& v, int x) {
    v.push_back(x);
    int idx = static_cast<int>(v.size()) - 1;
    while (idx > 0 and v[idx] < v[idx - 1]) {
        swap(v[idx], v[idx - 1]);
        --idx;
    }
}

void dfs1(const vi& partition, const vi& cur, int day, int idx, int k, int buf) {
    if (idx == partition.size()) {
        if (k <= buf) {
            follow.push_back(cur);
        }

        return;
    }

    if (seen[day][idx][k].count({partition, cur})) {
        return;
    }
    seen[day][idx][k].emplace(partition, cur);

    for (int i = 0; i <= min(k, partition[idx]); ++i) {
        vi nxt(begin(cur), end(cur));
        if (i > 1) {
            fast_insert(nxt, i);
        }
        if (partition[idx] - i > 1) {
            fast_insert(nxt, partition[idx] - i);
        }

        dfs1(partition, nxt, day, idx + 1, k - i, buf);
    }
}

map<vi, int> earliest;

// keep partitions sorted
void dfs0(const vi& partition, int day) {
    if (ans == num_employees)
        return;

    auto it = earliest.find(partition);
    int best = it == end(earliest) ? MAX_DAYS + 1 : it->second;
    if (day >= best) return;

    earliest[partition] = day;

    int uniq = num_employees;
    for (int x : partition) {
        uniq -= x;
    }
    ans = max(ans, uniq);
    if (ans == num_employees or day == num_days) {
        return;
    }

    follow.clear();
    vi cur;
    dfs1(partition, cur, day, 0, orders[day], uniq);
    vector<vi> nxts = follow;
    for (auto& v : nxts) {
        dfs0(v, day + 1);
    }
}

int main() {
    cin >> num_employees >> num_days;
    for (int i = 0; i < num_days; ++i) {
        cin >> orders[i];
        orders[i] = min(orders[i], num_employees - orders[i]);
    }
    sort(orders, orders + num_days, greater<int>());

    ans = 0;
    dfs0({num_employees}, 0);

    cout << ans << '\n';

    return 0;
}
