// A simple evolution strategy (ES) cheese solution.

import java.util.*;
import java.io.*;

public class lunchtime_es_font
{
   public static void main(String[] args) throws Exception
   {
      PrintWriter out = new PrintWriter(System.out);
      new lunchtime_es_font(new FastScanner(System.in), out);
      out.close();
   }

   int N, M;
   int[] counts;

   Solution genRandom()
   {
      Solution s = new Solution(N, M);
      for (int i=0; i<M; i++)
         for (int x=0; x<counts[i]; x++)
            s.matching[x][i] = 1;
      for (int i=0; i<M-1; i++)
         s.shuffleCol(i);
      return s;
   }

   public lunchtime_es_font(FastScanner in, PrintWriter out)
   {
      N = in.nextInt();
      M = in.nextInt();
      counts = new int[M];
      for (int i=0; i<M; i++)
      {
         int a = in.nextInt();
         counts[i] = Math.min(a, N-a);
      }
      Arrays.sort(counts);

      int numTrials = 100_000_000 / (N*M) + 1;

      int lambda = 200;
      int mu = 10;

      ArrayList<Solution> population = new ArrayList<>();

      int res = 0;
      for (int x=0; x<lambda; x++)
      {
         Solution s = genRandom();
         int rr = s.countUnique();
         if (rr > res)
            res = rr;
         population.add(s);
      }

      ArrayList<Solution> next_gen = new ArrayList<>();
      while (numTrials > 0)
      {
         Collections.sort(population);
         for (int x=0; x < lambda; x++)
         {
            int i = (int)(mu * Math.random());
            Solution s = population.get(i);
            Solution nxt = s.dup();
            int j = (int)((M-1) * Math.random());
            nxt.shuffleCol(j);
            next_gen.add(nxt);

            int rr = nxt.countUnique();
            if (rr > res)
               res = rr;
         }
      
         population.clear();
         for (Solution s : next_gen)
            population.add(s);
         next_gen.clear();

         numTrials -= lambda;
      }

      out.println(res);
   }
}

class Solution implements Comparable<Solution>
{
   static int[] freq = new int[1 << 11];
   int[][] matching;
   int fitness;

   Solution(int N, int M)
   {
      matching = new int[N][M]; 
   }

   Solution dup()
   {
      Solution s = new Solution(matching.length, matching[0].length);
      for (int i=0; i<matching.length; i++)
         for (int j=0; j<matching[0].length; j++)
            s.matching[i][j] = matching[i][j];
      return s;
   }

   void swap(int i, int j, int r, int c)
   {
      int tmp = matching[i][j];
      matching[i][j] = matching[r][c];
      matching[r][c] = tmp;
   }

   void shuffleCol(int c)
   {
      for (int i=1; i<matching.length; i++)
      {
         int j = (int)(Math.random() * i);
         swap(i, c, j, c);
      }
   }

   int countUnique()
   {
      int[] ids = new int[matching.length];
      for (int i=0; i<matching.length; i++)
      {
         int m = 0;
         for (int v : matching[i])
         {
            m = m << 1;
            m |= v;
         }
         ids[i] = m;
         freq[m]++;
      }

      int res = 0;
      for (int v : ids)
         if (freq[v] == 1)
            res++;
      
      for (int v : ids)
         freq[v]--;

      fitness = res;
      return res;
   }

   void print()
   {
      for (int[] cur : matching)
      {
         System.out.println(Arrays.toString(cur)); 
      }
   }

   public int compareTo(Solution rhs)
   {
      return Integer.compare(rhs.fitness, fitness);
   }
}

class FastScanner
{
   private InputStream stream;
   private byte[] buf = new byte[1024];
   private int curChar;
   private int numChars;
    
   public FastScanner(InputStream stream)
   {
      this.stream = stream;
   }
    
   int read()
   {
      if (numChars == -1)
         throw new InputMismatchException();
      if (curChar >= numChars)
      {
         curChar = 0;
         try
         {
            numChars = stream.read(buf);
         } 
         catch (IOException e) 
         {
            throw new InputMismatchException();
         }
         
         if (numChars <= 0)
            return -1;
      }
      return buf[curChar++];
   }
    
   boolean isSpaceChar(int c)
   {
      return c==' '||c=='\n'||c=='\r'||c=='\t'||c==-1;
   }
   
   boolean isEndline(int c)
   {
      return c=='\n'||c=='\r'||c==-1;
   }
   
   int nextInt()
   {
      return Integer.parseInt(next());
   }
   
   long nextLong()
   {
      return Long.parseLong(next());
   }
   
   double nextDouble()
   {
      return Double.parseDouble(next());
   }
   
   String next()
   {
      int c = read();
      while (isSpaceChar(c))
         c = read();
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isSpaceChar(c));
      return res.toString();
   }
   
   String nextLine()
   {
      int c = read();
      while (isEndline(c))
         c = read();
      
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isEndline(c));
      return res.toString();
   }
}
