// A randomized cheese solution to lunchtime

import java.util.*;
import java.io.*;

public class lunchtime_rand_font
{
   public static void main(String[] args) throws Exception
   {
      PrintWriter out = new PrintWriter(System.out);
      new lunchtime_rand_font(new FastScanner(System.in), out);
      out.close();
   }

   int N, M;
   int[] counts;

   Solution genRandom()
   {
      Solution s = new Solution(N, M);
      for (int i=0; i<M; i++)
         for (int x=0; x<counts[i]; x++)
            s.matching[x][i] = 1;
      for (int i=0; i<M; i++)
         s.shuffleCol(i);
      return s;
   }

   public lunchtime_rand_font(FastScanner in, PrintWriter out)
   {
      N = in.nextInt();
      M = in.nextInt();
      counts = new int[M];
      for (int i=0; i<M; i++)
      {
         int a = in.nextInt();
         counts[i] = Math.min(a, N-a);
      }
      Arrays.sort(counts);

      int numTrials = 100_000_000 / (N*M) + 1;

      int res = 0;
      for (int x=0; x<numTrials; x++)
      {
         Solution s = genRandom();
         int rr = s.countUnique();
         if (rr > res)
         {
            res = rr;
            //System.out.println(rr);
            //System.out.println("--------");
            //s.print();
         }
      }
      out.println(res);
   }
}

class Solution
{
   static int[] freq = new int[1 << 11];
   int[][] matching;

   Solution(int N, int M)
   {
      matching = new int[N][M]; 
   }

   void swap(int i, int j, int r, int c)
   {
      int tmp = matching[i][j];
      matching[i][j] = matching[r][c];
      matching[r][c] = tmp;
   }

   void shuffleCol(int c)
   {
      for (int i=1; i<matching.length; i++)
      {
         int j = (int)(Math.random() * i);
         swap(i, c, j, c);
      }
   }

   int countUnique()
   {
      int[] ids = new int[matching.length];
      for (int i=0; i<matching.length; i++)
      {
         int m = 0;
         for (int v : matching[i])
         {
            m = m << 1;
            m |= v;
         }
         ids[i] = m;
         freq[m]++;
      }

      int res = 0;
      for (int v : ids)
         if (freq[v] == 1)
            res++;
      
      for (int v : ids)
         freq[v]--;

      return res;
   }

   void print()
   {
      for (int[] cur : matching)
      {
         System.out.println(Arrays.toString(cur)); 
      }
   }
}

class FastScanner
{
   private InputStream stream;
   private byte[] buf = new byte[1024];
   private int curChar;
   private int numChars;
    
   public FastScanner(InputStream stream)
   {
      this.stream = stream;
   }
    
   int read()
   {
      if (numChars == -1)
         throw new InputMismatchException();
      if (curChar >= numChars)
      {
         curChar = 0;
         try
         {
            numChars = stream.read(buf);
         } 
         catch (IOException e) 
         {
            throw new InputMismatchException();
         }
         
         if (numChars <= 0)
            return -1;
      }
      return buf[curChar++];
   }
    
   boolean isSpaceChar(int c)
   {
      return c==' '||c=='\n'||c=='\r'||c=='\t'||c==-1;
   }
   
   boolean isEndline(int c)
   {
      return c=='\n'||c=='\r'||c==-1;
   }
   
   int nextInt()
   {
      return Integer.parseInt(next());
   }
   
   long nextLong()
   {
      return Long.parseLong(next());
   }
   
   double nextDouble()
   {
      return Double.parseDouble(next());
   }
   
   String next()
   {
      int c = read();
      while (isSpaceChar(c))
         c = read();
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isSpaceChar(c));
      return res.toString();
   }
   
   String nextLine()
   {
      int c = read();
      while (isEndline(c))
         c = read();
      
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isEndline(c));
      return res.toString();
   }
}
